@@ -80,6 +80,7 @@ def create_review_list(session_id, url, **kwargs):
         requests.exceptions.ConnectionError
     ) as e:
         time.sleep(3)
+        log.warning("Check the following file/directory after completion. At this point, the connection was broken")
         create_review_list(session_id, url, query=query, auth=kwargs["auth"])
 
     review_list = []
@@ -87,7 +88,8 @@ def create_review_list(session_id, url, **kwargs):
     try:
         json_content = json.loads(response.content)
     except json.decoder.JSONDecodeError:
-        get_session_id(LOGIN_URL, kwargs["auth"])
+        log.warning("Check the following file/directory after completion. At this point, the token was expired")
+        create_review_list(get_session_id(LOGIN_URL, kwargs["auth"]), url, query=query, auth=kwargs["auth"])
 
     if query == "":
         COUNT = len(json_content)
@@ -199,7 +201,7 @@ def create_fs_tree(session_id, root_path, review_list):
     except FileNotFoundError:
         os.mkdir(root_path)
     except FileExistsError:
-        root_path = os.path.join(root_path, "{0}_{1}".format("review", datetime.datetime.now(datetime.timezone.utc)
+        root_path = os.path.join(root_path, "{0}_{1}".format("reviews", datetime.datetime.now(datetime.timezone.utc)
             .replace(microsecond=0)
             .astimezone()
             .strftime("%d-%m-%yT%H_%M_%S")
